package org.playframework.playtools.popup.actions;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.FocusEvent;
import org.eclipse.swt.events.FocusListener;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.graphics.Rectangle;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.DirectoryDialog;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;
import org.playframework.playtools.PlayToolsPlugin;
import org.playframework.playtools.preferences.PreferenceConstants;
import org.playframework.playtools.util.PlayToolsUtil;

public class EclipsifyDialog extends Dialog {
	private Label locationLabel = null;
	private Combo playVersionCombo = null;
	private String playVersion = null;

	protected EclipsifyDialog(Shell parentShell) {
		super(parentShell);
	}

	protected Point getInitialSize() {
		return new Point(500, 120);
	}

	protected void okPressed() {

		playVersion = playVersionCombo.getText();
        if ("".equals(playVersion)) {
			MessageDialog dialog = new MessageDialog(getShell(),
					"Play Framework version Select",
					null,
					"Play Framework version please select",
					MessageDialog.ERROR,
					new String[]{"OK"}, 0);
			dialog.open();
        	return;
        }
		super.okPressed();
	}

	protected void configureShell(Shell newShell) {
		super.configureShell(newShell);
		newShell.setText("Play Framework version Select");
	}

	protected Control createDialogArea(Composite parent) {
		Composite composite = (Composite)super.createDialogArea(parent);

		composite.setSize(new Point(480, 100));

        Font font = parent.getFont();

        GridLayout layout = new GridLayout();
        layout.numColumns = 2;
        layout.verticalSpacing = 3;

        composite.setLayout(layout);
        composite.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
        composite.setFont(font);

        locationLabel = new Label(composite, SWT.NONE);
        locationLabel.setFont(font);
        locationLabel.setText("Play Framework version:");

		String location = PlayToolsPlugin.getDefault()
				.getPreferenceStore().getString(PreferenceConstants.P_PATH_PLAY);
		String items[] = PlayToolsUtil.paserLocationVersion(location);

		playVersionCombo = new Combo(composite, SWT.READ_ONLY);

		GridData data = new GridData(GridData.FILL_HORIZONTAL);
		data.widthHint = 120;
		playVersionCombo.setLayoutData(data);
		playVersionCombo.setFont(font);

		playVersionCombo.setItems(items);

		if (playVersion != null) {
			playVersionCombo.setText(playVersion);
		}
        return composite;
	}

	public void setPlayVersion(String playVersion) {
    	this.playVersion = playVersion;
    	if (playVersionCombo != null) {
			playVersionCombo.setText(playVersion);
    	}
    }
	public String getPlayVersion() {
    	return this.playVersion;
    }

}
