package org.playframework.playtools.preferences;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.FocusAdapter;
import org.eclipse.swt.events.FocusEvent;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.DirectoryDialog;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;
import org.playframework.playtools.util.PlayToolsUtil;

public class LocationDialog extends Dialog {

    private static final int C_TEXT_WIDTH = 200;

    private String playDirectory = "";
    private String playVersion = "";
    private String serverPort = "";

	private Label locationLabel = null;
	private Text locationPathText = null;
	private Button browseButton = null;

	private Label versionLabel = null;
	private Text versionText = null;

	private Label portLabel = null;
	private Text portText = null;


	protected LocationDialog(Shell parentShell) {
		super(parentShell);
	}

	protected Point getInitialSize() {
		return new Point(600, 180);
	}

	protected void okPressed() {
        playDirectory = locationPathText.getText();

        playVersion = PlayToolsUtil.searchPlayVersion(playDirectory);

        versionText.setText(playVersion);

        serverPort = portText.getText();

        if ("".equals(playVersion)) {
			MessageDialog dialog = new MessageDialog(getShell(),
					"Play Framework Install Directory",
					null,
					"Play Framework installation directory not done",
					MessageDialog.ERROR,
					new String[]{"OK"}, 0);
			dialog.open();
        	return;
        }
		super.okPressed();
	}
	protected void configureShell(Shell newShell) {
		super.configureShell(newShell);
		newShell.setText("Play Install Directory Select");
	}

	protected Control createDialogArea(Composite parent) {
		Composite composite = (Composite)super.createDialogArea(parent);

        Font font = parent.getFont();

        GridLayout layout = new GridLayout();
        layout.numColumns = 3;
        layout.verticalSpacing = 5;

        composite.setLayout(layout);
        composite.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
        composite.setFont(font);

        locationLabel = new Label(composite, SWT.NONE);
        locationLabel.setFont(font);
        locationLabel.setText("Director&y:");

        locationPathText = new Text(composite, SWT.BORDER);
        GridData data = new GridData(GridData.FILL_HORIZONTAL);
        data.widthHint = C_TEXT_WIDTH;
        locationPathText.setLayoutData(data);
        locationPathText.setFont(font);
        locationPathText.setEnabled(true);
        locationPathText.setText(playDirectory);
        locationPathText.addFocusListener(new FocusAdapter() {
			public void focusLost(FocusEvent e) {
				boolean change = false;
				if (!playDirectory.equals(locationPathText.getText())) {
					change = true;
				}
				playDirectory = locationPathText.getText();
		        playVersion = PlayToolsUtil.searchPlayVersion(playDirectory);
		        versionText.setText(playVersion);

		        if (change) {
			        int id = PlayToolsUtil.getPlayFrameworkVersionID(playVersion);
			        if (id == PlayToolsUtil.PLAY_VERSION_1) {
			        	portText.setText(PlayToolsUtil.PLAY_VERSION1_SERVER_PORT);
			        } else if (id == PlayToolsUtil.PLAY_VERSION_2) {
			        	portText.setText(PlayToolsUtil.PLAY_VERSION2_SERVER_PORT);
			        }
		        }
			}
        });

        browseButton = new Button(composite, SWT.PUSH);
        browseButton.setFont(font);
        browseButton.setText("B&rowse");
        browseButton.addSelectionListener(new SelectionAdapter() {
            public void widgetSelected(SelectionEvent event) {
                handleBrowse();
            }
        });
        browseButton.setEnabled(true);

        versionLabel = new Label(composite, SWT.NONE);
        versionLabel.setFont(font);
        versionLabel.setText("Play Framework Version:");

        versionText = new Text(composite, SWT.BORDER);
        data = new GridData(GridData.FILL_HORIZONTAL);
        data.widthHint = C_TEXT_WIDTH;
        versionText.setLayoutData(data);
        versionText.setFont(font);
        versionText.setEnabled(false);
        versionText.setText(playVersion);

        Label dummy = new Label(composite, SWT.NONE);

        portLabel = new Label(composite, SWT.NONE);
        portLabel.setFont(font);
        portLabel.setText("Server port:");

        portText = new Text(composite, SWT.BORDER);
        data = new GridData(GridData.FILL_HORIZONTAL);
        data.widthHint = C_TEXT_WIDTH;
        portText.setLayoutData(data);
        portText.setFont(font);
        portText.setEnabled(true);
        portText.setText(serverPort);

        return composite;
	}

    private void handleBrowse() {
        DirectoryDialog dialog = new DirectoryDialog(locationPathText.getShell());
        dialog.setMessage("Select the project contents directory.");

        String selectedDirectory = dialog.open();
        if (selectedDirectory != null) {
			boolean change = false;
			if (!playDirectory.equals(selectedDirectory)) {
				change = true;
			}
        	playDirectory = selectedDirectory;
            locationPathText.setText(playDirectory);
            playVersion = PlayToolsUtil.searchPlayVersion(playDirectory);
	        versionText.setText(playVersion);

	        if (change) {
		        int id = PlayToolsUtil.getPlayFrameworkVersionID(playVersion);
		        if (id == PlayToolsUtil.PLAY_VERSION_1) {
		        	portText.setText(PlayToolsUtil.PLAY_VERSION1_SERVER_PORT);
		        } else if (id == PlayToolsUtil.PLAY_VERSION_2) {
		        	portText.setText(PlayToolsUtil.PLAY_VERSION2_SERVER_PORT);
		        }
	        }
        }
    }

    public void setPlayDirectory(String playDirectory) {
    	this.playDirectory = playDirectory;
    	if (locationPathText != null) {
    		locationPathText.setText(playDirectory);
    	}
    }

    public String getPlayDirectory() {
    	return this.playDirectory;
    }

    public void setPlayVersion(String playVersion) {
    	this.playVersion = playVersion;
    	if (versionText != null) {
    		versionText.setText(playVersion);
    	}
    }

    public String getPlayVersion() {
    	return this.playVersion;
    }

    public void setServerPort(String serverPort) {
    	this.serverPort = serverPort;
    	if (portText != null) {
    		portText.setText(serverPort);
    	}
    }

    public String getServerPort() {
    	return this.serverPort;
    }

}
