package org.playframework.playtools.util.config;

import java.util.Random;

import org.eclipse.core.resources.IContainer;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IProjectDescription;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.IWorkspaceRoot;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.Path;
import org.playframework.playtools.util.PlayToolsUtil;
import org.playframework.playtools.util.console.PlayMessageConsole;
import org.playframework.playtools.util.invoker.Play2Launcher;

public class PlayConfigManagerVersion2  extends AbstractPlayConfigManager  {

	private static final String PATH_SETTING = "/.settings";
	private static final String PATH_APP = "/app";
	private static final String PATH_CONTROLLERS = PATH_APP + "/controllers";
	private static final String PATH_VIEWS = PATH_APP + "/views";
	private static final String PATH_CONF = "/conf";
	private static final String PATH_PROJECT = "/project";
	private static final String PATH_PUBLIC = "/public";
	private static final String PATH_IMAGES = PATH_PUBLIC + "/images";
	private static final String PATH_JAVASCRIPTS = PATH_PUBLIC + "/javascripts";
	private static final String PATH_STYLESHEETS = PATH_PUBLIC + "/stylesheets";
	private static final String PATH_TEST = "/test";
	private static final String PATH_FRAMEWORK = "/framework";
	private static final String PATH_RESOURCE = PATH_FRAMEWORK + "/skeletons";
	private static final String PATH_RESOURCE_EMPTY_SKEL = PATH_RESOURCE + "/empty-skel";
	private static final String PATH_RESOURCE_JAVA_SKEL = PATH_RESOURCE + "/java-skel";
	private static final String PATH_RESOURCE_SCALA_SKEL = PATH_RESOURCE + "/scala-skel";

	protected static PlayMessageConsole messageConsole = null;

	public PlayConfigManagerVersion2() {
	}

	public PlayConfigManagerVersion2(String version, int aplication, String payRootPath) {
		this.version = version;
		this.aplication = aplication;
		this.payRootPath = payRootPath;
	}

	public void createPlayProject(IProject projectHandle,
			IProjectDescription description, IProgressMonitor monitor) {

		String playPath = getPlayRootPathTrim();

		IWorkspaceRoot root = ResourcesPlugin.getWorkspace().getRoot();
		IResource resource = root.findMember(new Path(getProjectName()));
		IContainer container = (IContainer) resource;

		createFolder(monitor, container, PATH_SETTING);

		// empty-skel は不要
		if (aplication != PlayToolsUtil.PLAY_PROJECT_APPLICATION_EMPTY) {
			createFolder(monitor, container, PATH_APP);
			createFolder(monitor, container, PATH_CONTROLLERS);
			createFolder(monitor, container, PATH_VIEWS);
		}
		// empty-skel は不要


		createFolder(monitor, container, PATH_CONF);
		createFolder(monitor, container, PATH_PROJECT);

		createFolder(monitor, container, PATH_PUBLIC);
		createFolder(monitor, container, PATH_IMAGES);
		createFolder(monitor, container, PATH_JAVASCRIPTS);
		createFolder(monitor, container, PATH_STYLESHEETS);
		createFolder(monitor, container, PATH_TEST);

		String applicationPath = playPath + PATH_RESOURCE_JAVA_SKEL;

		if (aplication == PlayToolsUtil.PLAY_PROJECT_APPLICATION_EMPTY) {
			applicationPath = playPath + PATH_RESOURCE_EMPTY_SKEL;
		} else if(aplication == PlayToolsUtil.PLAY_PROJECT_APPLICATION_SCALA) {
			applicationPath = playPath + PATH_RESOURCE_SCALA_SKEL;
		}

		createRootToStream(projectHandle, applicationPath, ".gitignore");
		createRootToStream(projectHandle, applicationPath, "README");
        createRootFile(projectHandle, FILE_VERSION, PLAY_ECLIPSE_VERTION + getPlayVersion());

		// empty-skel は不要
		if (aplication != PlayToolsUtil.PLAY_PROJECT_APPLICATION_EMPTY) {
			String ext = "java";
			if (aplication == PlayToolsUtil.PLAY_PROJECT_APPLICATION_SCALA) {
				ext = "scala";
			}
	        createFileToStream(projectHandle, applicationPath, PATH_CONTROLLERS, "Application." + ext);
	        createFileToStream(projectHandle, applicationPath, PATH_VIEWS, "index.scala.html");
	        createFileToStream(projectHandle, applicationPath, PATH_VIEWS, "main.scala.html");
		}
		// empty-skel は不要

        createFileToStream(projectHandle, applicationPath, PATH_CONF, "routes");

        createFileToStream(projectHandle, applicationPath, PATH_PROJECT, "build.properties");
        createProjectFiles(projectHandle, applicationPath, PATH_PROJECT, "Build.scala");
        createProjectFiles(projectHandle, applicationPath, PATH_PROJECT, "plugins.sbt");

        createFileToStream(projectHandle, applicationPath, PATH_IMAGES, "favicon.png");
        createFileToStream(projectHandle, applicationPath, PATH_JAVASCRIPTS, "jquery-1.7.1.min.js");
        createFileToStream(projectHandle, applicationPath, PATH_STYLESHEETS, "main.css");

        createApplicationConfig(projectHandle, applicationPath, PATH_CONF);

        createClasspath(projectHandle);
	}

	private void createApplicationConfig(IProject projectHandle,
			String srcPath, String destPath) {

		String buf = readFile(srcPath + destPath + "/" + FILE_APPLICATION);

		String key = secretKey();

		createFile(projectHandle, destPath, FILE_APPLICATION, buf.replace("%APPLICATION_SECRET%", key));
	}

    private static String secretKey() {
	    Random rnd = new Random();

	    StringBuffer stringBuffer = new StringBuffer();
	    for (int i = 0; i < 64; i++) {
	    	int ran = rnd.nextInt(74) + 48;
	    	stringBuffer.append(Character.toString((char) ran).replace("\\", "/"));
	    }
	    return stringBuffer.toString();
    }

    private void createProjectFiles(IProject projectHandle,
								String srcPath, String destPath, String filename) {
		String buf = readFile(srcPath + destPath + "/" + filename);

		buf = buf.replace("%APPLICATION_NAME%", getProjectName());
		buf = buf.replace("%PLAY_VERSION%", getPlayVersion());

		createFile(projectHandle, destPath, filename, buf);
    }
	public void createClasspath(IProject projectHandle) {
		String payRootPath = getPlayRootPathTrim();
		String projectPath = getWorkspacePath() + "/" + getProjectPath();

		String consoleTitle = "play framework";

		messageConsole = new PlayMessageConsole(consoleTitle);

		Play2Launcher lancher = new Play2Launcher(messageConsole);

		lancher.execBuld(payRootPath, version, projectPath, true);
	}

	public void createPlayProjectFile() {
	}

    public void createVersionFile(IProject projectHandle) {
    	createRootFile(projectHandle, FILE_VERSION, PLAY_ECLIPSE_VERTION + getPlayVersion());
  }

}
