package org.playframework.playtools.util.invoker;

import org.playframework.playtools.util.PlayToolsUtil;
import org.playframework.playtools.util.console.PlayMessageConsole;

public abstract class AbstractPlayInvoker implements IPlayInvoker {
	public static final int PLAY_START_OK = 0;
	public static final int PLAY_ROOT_PAT_NONE = 1;
	public static final int PLAY_SELECT_PROJECT_NONE = 2;

	protected static PlayMessageConsole messageConsole = null;
	protected static String consoleTitle = null;
	protected static IPlayLauncher lancher = null;

	protected String payRootPath = null;
	protected String version = null;
	protected String projectPath = null;
	protected String port = null;

	public AbstractPlayInvoker() {
	}

	public AbstractPlayInvoker(String payRootPath, String version, String projectPath, String port) {
		this.payRootPath = payRootPath;
		this.version = version;
		this.projectPath = projectPath;
		this.port = port;

		consoleTitle = "play framework";
	}

	public int isStart() {
		String path = PlayToolsUtil.getSelectProjectPath();
		if ("".equals(path)) {
        	return PLAY_SELECT_PROJECT_NONE;
		}
		String playPath = PlayToolsUtil.getProjectPlayRootPath(path);
        if ("".equals(playPath)) {
        	return PLAY_ROOT_PAT_NONE;
        }
		return PLAY_START_OK;
	}

	public int startPlay() {
		stopPlay();
		launchPlay();
		return PLAY_START_OK;
	}

	public void stopPlay() {
		if (lancher != null) {
			if (messageConsole != null) {
				messageConsole.println("\n" + consoleTitle + " version " + version + " stop...");
			}

			lancher.terminate();

			lancher = null;
		}
	}

	protected void launchPlay() {}

	public void eclipsify(String frameworkPath, String version, String projectPath) {}

}
