package org.playframework.playtools.util.invoker;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.debug.core.DebugException;
import org.eclipse.debug.core.DebugPlugin;
import org.eclipse.debug.core.ILaunch;
import org.eclipse.debug.core.ILaunchManager;
import org.eclipse.debug.core.Launch;
import org.eclipse.debug.core.model.IProcess;
import org.eclipse.jdt.launching.IVMRunner;
import org.eclipse.jdt.launching.JavaRuntime;
import org.eclipse.jdt.launching.VMRunnerConfiguration;
import org.playframework.playtools.util.PlayToolsUtil;
import org.playframework.playtools.util.console.PlayMessageConsole;

public class Play1Launcher extends Thread implements IPlayLauncher {
	private ILaunch launch = null;
	private PlayMessageConsole messageConsole = null;
	private Process process = null;
	private String payRootPath = null;
	private String version = null;
	private String projectPath = null;
	private List<String> listCommand = new ArrayList<String>();

	public Play1Launcher() {

	}
	public Play1Launcher(PlayMessageConsole messageConsole) {
		this.messageConsole = messageConsole;
	}

	public void execBuld(String payRootPath, String version, String projectPath, boolean wait) {
		this.payRootPath = payRootPath;
		this.version = version;
		this.projectPath = projectPath;

		listCommand.clear();
		listCommand.add("clean");
		listCommand.add("eclipsify");

		this.start();

	}

	public void execReBuld(String payRootPath, String version, String projectPath, boolean wait) {
		execBuld(payRootPath, version, projectPath, wait);
	}

	public void run() {
		for (Object comman : listCommand) {
			execCmd(payRootPath,version, projectPath, (String)comman);
		}
		listCommand.clear();

		messageConsole.println("play framework version " + version + " eclipsify end...");

		terminate();
	}
	private void execCmd(String payRootPath, String version, String projectPath, String command) {

		File dir = new File(projectPath);

		List<String> argList = new ArrayList<String>();

		argList.add(payRootPath + "/python/python.exe");
		argList.add(payRootPath + "/play");
		argList.add(command);

		try {
			process = Runtime.getRuntime().exec((String[])argList.toArray(new String[argList.size()]), null, dir);

			launch = new Launch(null, ILaunchManager.RUN_MODE, null);
			IProcess proc = DebugPlugin.newProcess(launch , process, "");
			proc.getStreamsProxy().getOutputStreamMonitor().addListener(messageConsole.getListener());
			proc.getStreamsProxy().getErrorStreamMonitor().addListener(messageConsole.getListener());

			process.waitFor();

		} catch (IOException e) {
			e.printStackTrace();
		} catch (InterruptedException e) {
			e.printStackTrace();
		}
	}

	public void execPlay(String payRootPath, String version, String projectPath, String port) {
		execPlayCmd(payRootPath,version, projectPath, port);
	}

	private void execPlayCmd(String payRootPath, String version, String projectPath, String port) {

		List<String> listClass = PlayToolsUtil.getClasspath(payRootPath);
		listClass.add(projectPath + "/conf");

		List<String> argList = new ArrayList<String>();

		argList.add("-XX:-UseSplitVerifier");
		argList.add("-Dfile.encoding=utf-8");
		argList.add("-Xrunjdwp:transport=dt_socket,address=" + port + ",server=y,suspend=n");
		argList.add("-Xdebug");
		argList.add("-Dplay.debug=yes");
		argList.add("-Dapplication.path=" + projectPath);

        VMRunnerConfiguration vmConfig = new VMRunnerConfiguration("play.server.Server", (String[])listClass.toArray(new String[listClass.size()]));

		vmConfig.setVMArguments((String[])argList.toArray(new String[argList.size()]));

		IVMRunner vmRunner = JavaRuntime.getDefaultVMInstall().getVMRunner(ILaunchManager.RUN_MODE);

		launch = new Launch(null, ILaunchManager.RUN_MODE, null);

		try {
			vmRunner.run(vmConfig, launch, null);
		} catch (CoreException e) {
			e.printStackTrace();
		}

		DebugPlugin.getDefault().getLaunchManager().addLaunch(launch);

        launch.getProcesses()[0].getStreamsProxy().getOutputStreamMonitor().addListener(messageConsole.getListener());
        launch.getProcesses()[0].getStreamsProxy().getErrorStreamMonitor().addListener(messageConsole.getListener());

	}

	public void terminate() {
		if (launch != null) {
			try {
				launch.terminate();
				DebugPlugin.getDefault().getLaunchManager().removeLaunch(launch);
			} catch (DebugException e) {
				e.printStackTrace();
			}
			launch = null;
		}
	}

}
