package org.playframework.playtools.util.invoker;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.eclipse.debug.core.DebugException;
import org.eclipse.debug.core.DebugPlugin;
import org.eclipse.debug.core.ILaunch;
import org.eclipse.debug.core.ILaunchManager;
import org.eclipse.debug.core.Launch;
import org.eclipse.debug.core.model.IProcess;
import org.playframework.playtools.util.console.PlayMessageConsole;

public class Play2Launcher extends Thread implements IPlayLauncher {

	private ILaunch launch = null;
	private PlayMessageConsole messageConsole = null;
	private Process process = null;
	private String payRootPath = null;
	private String version = null;
	private String projectPath = null;
	private List<String> listCommand = new ArrayList<String>();

	public Play2Launcher() {

	}
	public Play2Launcher(PlayMessageConsole messageConsole) {
		this.messageConsole = messageConsole;
	}

	public void execBuld(String payRootPath, String version, String projectPath, boolean wait) {
		this.payRootPath = payRootPath;
		this.version = version;
		this.projectPath = projectPath;

		listCommand.clear();
		listCommand.add("eclipsify");

		if (wait) {
			this.run();
		} else {
			this.start();
		}
	}

	public void execReBuld(String payRootPath, String version, String projectPath, boolean wait) {
		this.payRootPath = payRootPath;
		this.version = version;
		this.projectPath = projectPath;

		listCommand.clear();
		listCommand.add("clean");
		listCommand.add("eclipsify");

		if (wait) {
			this.run();
		} else {
			this.start();
		}
	}

	public void run() {

		for (Object comman : listCommand) {
			execCmd(payRootPath,version, projectPath, "", (String)comman, true);
		}
		listCommand.clear();

		messageConsole.println("play framework version " + version + " eclipsify end...");

		terminate();
	}

	public void execPlay(String payRootPath, String version, String projectPath, String port) {
		String debug = "\"-Xrunjdwp:transport=dt_socket,server=y,suspend=n,address=" + port + "\"";

		execCmd(payRootPath,version, projectPath, debug, "run", false);

	}

	private void execCmd(String payRootPath, String version, String projectPath, String debug, String command, boolean wait) {

		String frameworkPath = payRootPath + "/framework";
		File dir = new File(projectPath);

		List<String> argList = new ArrayList<String>();

		argList.add("java");
		argList.add("-Xms512M");
		argList.add("-Xmx1024M");
		argList.add("-Xss1M");
		argList.add("-XX:+CMSClassUnloadingEnabled");
		argList.add("-XX:MaxPermSize=256M");
		argList.add("-Dfile.encoding=UTF8");
		argList.add("-Dplay.version=\"" + version + "\"");
		argList.add("-Dsbt.ivy.home=\"" + frameworkPath + "/../repository\"");
		argList.add("-Dplay.home=\"" + frameworkPath + "/.\"");
		argList.add("-Dsbt.boot.properties=\"file:///" + frameworkPath + "/sbt/sbt.boot.properties\"");
		if (debug.length() > 0) {
			argList.add(debug);
		}
		argList.add("-jar");
		argList.add("\"" + frameworkPath + "/sbt/sbt-launch.jar\"");
		argList.add(command);

		try {
			process = Runtime.getRuntime().exec((String[])argList.toArray(new String[argList.size()]), null, dir);
			launch = new Launch(null, ILaunchManager.RUN_MODE, null);
			IProcess proc = DebugPlugin.newProcess(launch , process, "");
			proc.getStreamsProxy().getOutputStreamMonitor().addListener(messageConsole.getListener());
			proc.getStreamsProxy().getErrorStreamMonitor().addListener(messageConsole.getListener());
			if (wait) {
				process.waitFor();
			}
		} catch (IOException e) {
			e.printStackTrace();
		} catch (InterruptedException e) {
			e.printStackTrace();
		}
	}

	public void terminate() {
		if (launch != null) {
			try {
				launch.terminate();
				DebugPlugin.getDefault().getLaunchManager().removeLaunch(launch);
			} catch (DebugException e) {
				e.printStackTrace();
			}
			launch = null;
		}
		listCommand.clear();
	}
}
