package org.playframework.playtools.util.invoker;

import org.playframework.playtools.util.PlayToolsUtil;

public class PlayInvoker {

	private static IPlayInvoker invoker = null;

	public static final int PLAY_START_NG = -1;
	public static final int PLAY_START_OK = 0;
	public static final int PLAY_ROOT_PAT_NONE = 1;
	public static final int PLAY_SELECT_PROJECT_NONE = 2;

	public PlayInvoker() {
	}

	public static int isStart() {
		return PlayToolsUtil.isStart();
	}

	public static int startPlay() {
		int result = isStart();
		if (result != PLAY_START_OK) {
			return result;
		}

		String projectPath = PlayToolsUtil.getSelectProjectPath();
		String version = PlayToolsUtil.getPlayVersion(projectPath);
		String frameworkPath = PlayToolsUtil.getPlayRootPath(version);
		String port = PlayToolsUtil.getServerPort(version);

		int id = PlayToolsUtil.getPlayFrameworkVersionID(version);
		if (id == PlayToolsUtil.PLAY_VERSION_1) {
			invoker = new PlayInvokerVersion1(frameworkPath, version, projectPath, port);
		} else if (id == PlayToolsUtil.PLAY_VERSION_2) {
			invoker = new PlayInvokerVersion2(frameworkPath, version, projectPath, port);
		}
		if (invoker != null) {
			invoker.startPlay();
			return PLAY_START_OK;
		}
		return PLAY_START_NG;
	}

	public static void stopPlay() {
		if (invoker != null) {
			invoker.stopPlay();
			invoker = null;
		}
	}

	public static int eclipsify(String frameworkPath, String version, String projectPath) {
		IPlayInvoker invoker = null;
		int id = PlayToolsUtil.getPlayFrameworkVersionID(version);
		if (id == PlayToolsUtil.PLAY_VERSION_1) {
			invoker = new PlayInvokerVersion1(frameworkPath, version, projectPath, "");
		} else if (id == PlayToolsUtil.PLAY_VERSION_2) {
			invoker = new PlayInvokerVersion2(frameworkPath, version, projectPath, "");
		}
		if (invoker != null) {
			invoker.eclipsify(frameworkPath, version, projectPath);
			return PLAY_START_OK;
		}
		return PLAY_START_NG;
	}

	public static int reEclipsify(String frameworkPath, String version, String projectPath) {
		IPlayInvoker invoker = null;
		int id = PlayToolsUtil.getPlayFrameworkVersionID(version);
		if (id == PlayToolsUtil.PLAY_VERSION_1) {
			invoker = new PlayInvokerVersion1(frameworkPath, version, projectPath, "");
		} else if (id == PlayToolsUtil.PLAY_VERSION_2) {
			invoker = new PlayInvokerVersion2(frameworkPath, version, projectPath, "");
		}
		if (invoker != null) {
			invoker.reEclipsify(frameworkPath, version, projectPath);
			return PLAY_START_OK;
		}
		return PLAY_START_NG;
	}
}
